@@ -26,9 +26,9 @@ pub trait SecretExt: super::ResourceExt + Sized {
     #[must_use]
     fn r#type(self, r#type: impl ToString) -> Self;
     #[must_use]
-    fn data(self, data: impl IntoIterator<Item = (String, ByteString)>) -> Self;
+    fn data(self, data: impl IntoIterator<Item = (impl ToString, ByteString)>) -> Self;
     #[must_use]
-    fn string_data(self, data: impl IntoIterator<Item = (String, String)>) -> Self;
+    fn string_data(self, data: impl IntoIterator<Item = (impl ToString, impl ToString)>) -> Self;
     fn image_pull_secret(name: impl ToString, data: impl ToString) -> Self {
         let data = Some((DOCKER_CONFIG_JSON_KEY.to_string(), data.to_string()));
         Self::new(name)
@@ -60,16 +60,22 @@ impl SecretExt for corev1::Secret {
         Self { type_, ..self }
     }
 
-    fn data(self, data: impl IntoIterator<Item = (String, ByteString)>) -> Self {
-        let data = data.into_iter().collect();
+    fn data(self, data: impl IntoIterator<Item = (impl ToString, ByteString)>) -> Self {
+        let data = data
+            .into_iter()
+            .map(|(key, value)| (key.to_string(), value))
+            .collect();
         Self {
             data: Some(data),
             ..self
         }
     }
 
-    fn string_data(self, data: impl IntoIterator<Item = (String, String)>) -> Self {
-        let data = data.into_iter().collect();
+    fn string_data(self, data: impl IntoIterator<Item = (impl ToString, impl ToString)>) -> Self {
+        let data = data
+            .into_iter()
+            .map(|(key, value)| (key.to_string(), value.to_string()))
+            .collect();
         Self {
             string_data: Some(data),
             ..self
