@@ -592,6 +592,26 @@ impl super::Kubectl {
     }
 }
 
+/// convert `configmap` key: `K`
+///
+/// #errors:
+///
+/// from https://kubernetes.io/docs/concepts/configuration/configmap/
+/// ```field must consist of alphanumeric characters, -, _ or ..```
+fn try_key_to_string<K>(key: &K) -> anyhow::Result<String>
+where
+    K: ToString,
+{
+    let key = key.to_string();
+
+    anyhow::ensure!(
+        key.chars()
+            .all(|ch| ch.is_alphanumeric() || ['-', '_', ','].contains(&ch)),
+        "{} contains non alphanumeric or in ['-', '_', ','] character",
+        key
+    );
+    Ok(key)
+}
 /// an try-update function that takes a `confimap.data`: `BTreeMap<String, String>`
 /// and applies `update_fn: impl FnMut(&mut BTreeMap<K, V>)`
 fn try_update_json_configmap<K, V>(
@@ -624,10 +644,11 @@ where
             )
         })?;
     update_fn(&mut data);
+
     *cm_data = data
         .iter()
-        .map(|(key, value)| Ok((key.to_string(), to_string(value)?)))
-        .collect::<serde_json::Result<_>>()
+        .map(|(key, value)| Ok((try_key_to_string(key)?, to_string(value)?)))
+        .collect::<anyhow::Result<_>>()
         .with_context(|| format!("serialize configmap {:?} after update", cm_data))?;
 
     Ok(())
